summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libwebp/src/enc/histogram_enc.h
diff options
context:
space:
mode:
authorTarja Sundqvist <tarja.sundqvist@qt.io>2022-09-12 18:29:49 +0300
committerTarja Sundqvist <tarja.sundqvist@qt.io>2022-09-12 18:29:49 +0300
commit7824fe51318b8a87caa9ef3ed4db99914e22e6e4 (patch)
tree7b861acefc1acb41a8bc806dfa7693aa41f53263 /src/3rdparty/libwebp/src/enc/histogram_enc.h
parent3c316057a0e6dae324f92a3bef2c31c398c2ea51 (diff)
parent6c0e0f2a82d8d26e33eb7190066c9872a00a0f8b (diff)
Merge remote-tracking branch 'origin/tqtc/lts-5.15.7' into tqtc/lts-5.15-opensourcev5.15.7-lts-lgpl
Diffstat (limited to 'src/3rdparty/libwebp/src/enc/histogram_enc.h')
-rw-r--r--src/3rdparty/libwebp/src/enc/histogram_enc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/3rdparty/libwebp/src/enc/histogram_enc.h b/src/3rdparty/libwebp/src/enc/histogram_enc.h
index 54c2d21..c3428b5 100644
--- a/src/3rdparty/libwebp/src/enc/histogram_enc.h
+++ b/src/3rdparty/libwebp/src/enc/histogram_enc.h
@@ -64,8 +64,8 @@ void VP8LHistogramCreate(VP8LHistogram* const p,
const VP8LBackwardRefs* const refs,
int palette_code_bits);
-// Return the size of the histogram for a given palette_code_bits.
-int VP8LGetHistogramSize(int palette_code_bits);
+// Return the size of the histogram for a given cache_bits.
+int VP8LGetHistogramSize(int cache_bits);
// Set the palette_code_bits and reset the stats.
// If init_arrays is true, the arrays are also filled with 0's.
@@ -110,7 +110,7 @@ int VP8LGetHistoImageSymbols(int xsize, int ysize,
const VP8LBackwardRefs* const refs,
int quality, int low_effort,
int histogram_bits, int cache_bits,
- VP8LHistogramSet* const image_in,
+ VP8LHistogramSet* const image_histo,
VP8LHistogram* const tmp_histo,
uint16_t* const histogram_symbols);